=== modified file 'drizzled/db.cc'
--- drizzled/db.cc	2010-10-23 22:28:30 +0000
+++ drizzled/db.cc	2010-10-24 01:34:39 +0000
@@ -372,7 +372,7 @@
   for (table= tables; table; table= table->next_local)
   {
     const char *db=table->getSchemaName();
-    TableIdentifier identifier(table->getSchemaName(), table->table_name);
+    TableIdentifier identifier(table->getSchemaName(), table->getTableName());
 
     plugin::StorageEngine *table_type;
 
@@ -426,7 +426,7 @@
       // Table was not found on disk and table can't be created from engine
       push_warning_printf(session, DRIZZLE_ERROR::WARN_LEVEL_NOTE,
                           ER_BAD_TABLE_ERROR, ER(ER_BAD_TABLE_ERROR),
-                          table->table_name);
+                          table->getTableName());
     }
     else
     {
@@ -447,14 +447,14 @@
 
     if (error == 0 || (foreign_key_error == false))
     {
-      transaction_services.dropTable(session, string(db), string(table->table_name), true);
+      transaction_services.dropTable(session, string(db), string(table->getTableName()), true);
     }
 
     if (error)
     {
       if (wrong_tables.length())
         wrong_tables.append(',');
-      wrong_tables.append(String(table->table_name,system_charset_info));
+      wrong_tables.append(String(table->getTableName(),system_charset_info));
     }
   }
   /*
@@ -515,9 +515,9 @@
       return -1;
 
     table_list->setSchemaName((char*) (table_list+1));
-    table_list->table_name= strcpy((char*) (table_list+1), schema_identifier.getSchemaName().c_str()) + db_len + 1;
-    TableIdentifier::filename_to_tablename((*it).getTableName().c_str(), table_list->table_name, (*it).getTableName().size() + 1);
-    table_list->alias= table_list->table_name;  // If lower_case_table_names=2
+    table_list->setTableName(strcpy((char*) (table_list+1), schema_identifier.getSchemaName().c_str()) + db_len + 1);
+    TableIdentifier::filename_to_tablename((*it).getTableName().c_str(), const_cast<char *>(table_list->getTableName()), (*it).getTableName().size() + 1);
+    table_list->alias= table_list->getTableName();  // If lower_case_table_names=2
     table_list->setInternalTmpTable((strncmp((*it).getTableName().c_str(),
                                              TMP_FILE_PREFIX,
                                              strlen(TMP_FILE_PREFIX)) == 0));

=== modified file 'drizzled/field_iterator.cc'
--- drizzled/field_iterator.cc	2010-10-23 22:28:30 +0000
+++ drizzled/field_iterator.cc	2010-10-24 01:34:39 +0000
@@ -128,9 +128,9 @@
   if (table_ref->is_natural_join)
     return natural_join_it.column_ref()->table_name();
 
-  assert(!strcmp(table_ref->table_name,
-                      table_ref->table->getShare()->getTableName()));
-  return table_ref->table_name;
+  assert(!strcmp(table_ref->getTableName(),
+                 table_ref->table->getShare()->getTableName()));
+  return table_ref->getTableName();
 }
 
 

=== modified file 'drizzled/lock.cc'
--- drizzled/lock.cc	2010-10-23 22:28:30 +0000
+++ drizzled/lock.cc	2010-10-24 01:34:39 +0000
@@ -683,7 +683,7 @@
 static int lock_table_name(Session *session, TableList *table_list, bool check_in_use)
 {
   bool  found_locked_table= false;
-  TableIdentifier identifier(table_list->getSchemaName(), table_list->table_name);
+  TableIdentifier identifier(table_list->getSchemaName(), table_list->getTableName());
   const TableIdentifier::Key &key(identifier.getKey());
 
   if (check_in_use)

=== modified file 'drizzled/sql_base.cc'
--- drizzled/sql_base.cc	2010-10-23 22:28:30 +0000
+++ drizzled/sql_base.cc	2010-10-24 01:34:39 +0000
@@ -401,7 +401,7 @@
       bool found= false;
       for (TableList *table= tables; table; table= table->next_local)
       {
-        TableIdentifier identifier(table->getSchemaName(), table->table_name);
+        TableIdentifier identifier(table->getSchemaName(), table->getTableName());
         if (remove_table_from_cache(session, identifier,
                                     RTFC_OWNED_BY_Session_FLAG))
         {
@@ -592,7 +592,7 @@
   {
     if ((table->table == 0 || table->table->getShare()->getType() == message::Table::STANDARD) &&
         strcasecmp(table->getSchemaName(), db_name) == 0 &&
-        strcasecmp(table->table_name, table_name) == 0)
+        strcasecmp(table->getTableName(), table_name) == 0)
       break;
   }
   return table;
@@ -664,7 +664,7 @@
     assert(table);
   }
   d_name= table->getSchemaName();
-  t_name= table->table_name;
+  t_name= table->getTableName();
   t_alias= table->alias;
 
   for (;;)
@@ -972,15 +972,14 @@
 bool Session::reopen_name_locked_table(TableList* table_list)
 {
   Table *table= table_list->table;
-  char *table_name= table_list->table_name;
 
   safe_mutex_assert_owner(LOCK_open.native_handle());
 
   if (killed || not table)
     return true;
 
-  TableIdentifier identifier(table_list->getSchemaName(), table_list->table_name);
-  if (open_unireg_entry(this, table, table_name, identifier))
+  TableIdentifier identifier(table_list->getSchemaName(), table_list->getTableName());
+  if (open_unireg_entry(this, table, table_list->getTableName(), identifier))
   {
     table->intern_close_table();
     return true;
@@ -1143,7 +1142,7 @@
   if (killed)
     return NULL;
 
-  TableIdentifier identifier(table_list->getSchemaName(), table_list->table_name);
+  TableIdentifier identifier(table_list->getSchemaName(), table_list->getTableName());
   const TableIdentifier::Key &key(identifier.getKey());
   TableOpenCacheRange ppp;
 
@@ -1180,7 +1179,7 @@
   {
     if (flags & DRIZZLE_OPEN_TEMPORARY_ONLY)
     {
-      my_error(ER_NO_SUCH_TABLE, MYF(0), table_list->getSchemaName(), table_list->table_name);
+      my_error(ER_NO_SUCH_TABLE, MYF(0), table_list->getSchemaName(), table_list->getTableName());
       return NULL;
     }
 
@@ -1346,7 +1345,7 @@
 
         if (table_list->isCreate())
         {
-          TableIdentifier  lock_table_identifier(table_list->getSchemaName(), table_list->table_name, message::Table::STANDARD);
+          TableIdentifier  lock_table_identifier(table_list->getSchemaName(), table_list->getTableName(), message::Table::STANDARD);
 
           if (not plugin::StorageEngine::doesTableExist(*this, lock_table_identifier))
           {
@@ -1997,7 +1996,7 @@
      * to see if it exists so that an unauthorized user cannot phish for
      * table/schema information via error messages
      */
-    TableIdentifier the_table(tables->getSchemaName(), tables->table_name);
+    TableIdentifier the_table(tables->getSchemaName(), tables->getTableName());
     if (not plugin::Authorization::isAuthorized(getSecurityContext(),
                                                 the_table))
     {

=== modified file 'drizzled/sql_derived.cc'
--- drizzled/sql_derived.cc	2010-10-23 22:28:30 +0000
+++ drizzled/sql_derived.cc	2010-10-24 01:34:39 +0000
@@ -146,7 +146,7 @@
     {
       orig_table_list->derived_result= derived_result;
       orig_table_list->table= table;
-      orig_table_list->table_name=        const_cast<char *>(table->getShare()->getTableName());
+      orig_table_list->setTableName(const_cast<char *>(table->getShare()->getTableName()));
       orig_table_list->table_name_length= table->getShare()->getTableNameSize();
       table->derived_select_number= first_select->select_number;
       orig_table_list->setSchemaName((char *)"");

=== modified file 'drizzled/sql_insert.cc'
--- drizzled/sql_insert.cc	2010-10-22 23:21:19 +0000
+++ drizzled/sql_insert.cc	2010-10-24 01:34:39 +0000
@@ -1504,11 +1504,11 @@
       create_info->table_existed= 1;		// Mark that table existed
       push_warning_printf(session, DRIZZLE_ERROR::WARN_LEVEL_NOTE,
                           ER_TABLE_EXISTS_ERROR, ER(ER_TABLE_EXISTS_ERROR),
-                          create_table->table_name);
+                          create_table->getTableName());
       return create_table->table;
     }
 
-    my_error(ER_TABLE_EXISTS_ERROR, MYF(0), create_table->table_name);
+    my_error(ER_TABLE_EXISTS_ERROR, MYF(0), create_table->getTableName());
     return NULL;
   }
 
@@ -1593,7 +1593,7 @@
           or it was created via different mysqld front-end to the
           cluster. We don't have much options but throw an error.
         */
-        my_error(ER_TABLE_EXISTS_ERROR, MYF(0), create_table->table_name);
+        my_error(ER_TABLE_EXISTS_ERROR, MYF(0), create_table->getTableName());
         return NULL;
       }
 

=== modified file 'drizzled/sql_load.cc'
--- drizzled/sql_load.cc	2010-10-23 22:28:30 +0000
+++ drizzled/sql_load.cc	2010-10-24 01:34:39 +0000
@@ -170,7 +170,7 @@
   */
   if (unique_table(table_list, table_list->next_global))
   {
-    my_error(ER_UPDATE_TABLE_USED, MYF(0), table_list->table_name);
+    my_error(ER_UPDATE_TABLE_USED, MYF(0), table_list->getTableName());
     return(true);
   }
 

=== modified file 'drizzled/sql_parse.cc'
--- drizzled/sql_parse.cc	2010-10-23 22:28:30 +0000
+++ drizzled/sql_parse.cc	2010-10-24 01:34:39 +0000
@@ -968,7 +968,7 @@
   ptr->setIsAlias(alias ? true : false);
   if (table->table.length)
     table->table.length= my_casedn_str(files_charset_info, table->table.str);
-  ptr->table_name=table->table.str;
+  ptr->setTableName(table->table.str);
   ptr->table_name_length=table->table.length;
   ptr->lock_type=   lock_type;
   ptr->force_index= table_options.test(TL_OPTION_FORCE_INDEX);

=== modified file 'drizzled/sql_table.cc'
--- drizzled/sql_table.cc	2010-10-23 22:28:30 +0000
+++ drizzled/sql_table.cc	2010-10-24 01:34:39 +0000
@@ -160,7 +160,7 @@
 
   for (table= tables; table; table= table->next_local)
   {
-    TableIdentifier tmp_identifier(table->getSchemaName(), table->table_name);
+    TableIdentifier tmp_identifier(table->getSchemaName(), table->getTableName());
 
     error= session->drop_temporary_table(tmp_identifier);
 
@@ -196,7 +196,7 @@
         goto err_with_placeholders;
       }
     }
-    TableIdentifier identifier(table->getSchemaName(), table->table_name, table->getInternalTmpTable() ? message::Table::INTERNAL : message::Table::STANDARD);
+    TableIdentifier identifier(table->getSchemaName(), table->getTableName(), table->getInternalTmpTable() ? message::Table::INTERNAL : message::Table::STANDARD);
 
     if (drop_temporary || not plugin::StorageEngine::doesTableExist(*session, identifier))
     {
@@ -204,7 +204,7 @@
       if (if_exists)
         push_warning_printf(session, DRIZZLE_ERROR::WARN_LEVEL_NOTE,
                             ER_BAD_TABLE_ERROR, ER(ER_BAD_TABLE_ERROR),
-                            table->table_name);
+                            table->getTableName());
       else
         error= 1;
     }
@@ -228,14 +228,14 @@
     if (error == 0 || (if_exists && foreign_key_error == false))
     {
       TransactionServices &transaction_services= TransactionServices::singleton();
-      transaction_services.dropTable(session, string(table->getSchemaName()), string(table->table_name), if_exists);
+      transaction_services.dropTable(session, string(table->getSchemaName()), string(table->getTableName()), if_exists);
     }
 
     if (error)
     {
       if (wrong_tables.length())
         wrong_tables.append(',');
-      wrong_tables.append(String(table->table_name,system_charset_info));
+      wrong_tables.append(String(table->getTableName(), system_charset_info));
     }
   }
   /*
@@ -1760,7 +1760,7 @@
     char table_name[NAME_LEN*2+2];
     bool fatal_error=0;
 
-    snprintf(table_name, sizeof(table_name), "%s.%s", table->getSchemaName(),table->table_name);
+    snprintf(table_name, sizeof(table_name), "%s.%s", table->getSchemaName(), table->getTableName());
     table->lock_type= lock_type;
     /* open only one table from local list of command */
     {
@@ -2058,7 +2058,6 @@
                              bool is_if_not_exists,
                              bool is_engine_set)
 {
-  char *table_name= table->table_name;
   bool res= true;
   uint32_t not_used;
 
@@ -2168,14 +2167,14 @@
     {
       char warn_buff[DRIZZLE_ERRMSG_SIZE];
       snprintf(warn_buff, sizeof(warn_buff),
-               ER(ER_TABLE_EXISTS_ERROR), table_name);
+               ER(ER_TABLE_EXISTS_ERROR), table->getTableName());
       push_warning(session, DRIZZLE_ERROR::WARN_LEVEL_NOTE,
                    ER_TABLE_EXISTS_ERROR,warn_buff);
       res= false;
     }
     else
     {
-      my_error(ER_TABLE_EXISTS_ERROR, MYF(0), table_name);
+      my_error(ER_TABLE_EXISTS_ERROR, MYF(0), table->getTableName());
     }
   }
 

=== modified file 'drizzled/sql_union.cc'
--- drizzled/sql_union.cc	2010-10-23 22:28:30 +0000
+++ drizzled/sql_union.cc	2010-10-24 01:34:39 +0000
@@ -363,7 +363,7 @@
     memset(&result_table_list, 0, sizeof(result_table_list));
     result_table_list.setSchemaName((char*) "");
     result_table_list.alias= "union";
-    result_table_list.table_name= (char *) "union";
+    result_table_list.setTableName((char *) "union");
     result_table_list.table= table= union_result->table;
 
     session_arg->lex->current_select= lex_select_save;

=== modified file 'drizzled/sql_update.cc'
--- drizzled/sql_update.cc	2010-10-23 01:38:11 +0000
+++ drizzled/sql_update.cc	2010-10-24 01:34:39 +0000
@@ -638,7 +638,7 @@
     TableList *duplicate;
     if ((duplicate= unique_table(table_list, table_list->next_global)))
     {
-      my_error(ER_UPDATE_TABLE_USED, MYF(0), table_list->table_name);
+      my_error(ER_UPDATE_TABLE_USED, MYF(0), table_list->getTableName());
       return true;
     }
   }

=== modified file 'drizzled/sql_yacc.yy'
--- drizzled/sql_yacc.yy	2010-10-23 22:28:30 +0000
+++ drizzled/sql_yacc.yy	2010-10-24 01:34:39 +0000
@@ -5826,7 +5826,7 @@
               DRIZZLE_YYABORT;
             }
             if (my_strcasecmp(table_alias_charset, $3.str,
-                              table->table_name))
+                              table->getTableName()))
             {
               my_error(ER_WRONG_TABLE_NAME, MYF(0), $3.str);
               DRIZZLE_YYABORT;

=== modified file 'drizzled/statement/alter_table.cc'
--- drizzled/statement/alter_table.cc	2010-10-23 22:28:30 +0000
+++ drizzled/statement/alter_table.cc	2010-10-24 01:34:39 +0000
@@ -107,7 +107,7 @@
   /* Chicken/Egg... we need to search for the table, to know if the table exists, so we can build a full identifier from it */
   message::Table original_table_message;
   {
-    TableIdentifier identifier(first_table->getSchemaName(), first_table->table_name);
+    TableIdentifier identifier(first_table->getSchemaName(), first_table->getTableName());
     if (plugin::StorageEngine::getTableDefinition(*session, identifier, original_table_message) != EEXIST)
     {
       my_error(ER_BAD_TABLE_ERROR, MYF(0), identifier.getSQLPath().c_str());
@@ -146,9 +146,9 @@
   bool res;
   if (original_table_message.type() == message::Table::STANDARD )
   {
-    TableIdentifier identifier(first_table->getSchemaName(), first_table->table_name);
+    TableIdentifier identifier(first_table->getSchemaName(), first_table->getTableName());
     TableIdentifier new_identifier(select_lex->db ? select_lex->db : first_table->getSchemaName(),
-                                   session->lex->name.str ? session->lex->name.str : first_table->table_name);
+                                   session->lex->name.str ? session->lex->name.str : first_table->getTableName());
 
     res= alter_table(session, 
                      identifier,
@@ -164,13 +164,13 @@
   }
   else
   {
-    TableIdentifier catch22(first_table->getSchemaName(), first_table->table_name);
+    TableIdentifier catch22(first_table->getSchemaName(), first_table->getTableName());
     Table *table= session->find_temporary_table(catch22);
     assert(table);
     {
-      TableIdentifier identifier(first_table->getSchemaName(), first_table->table_name, table->getMutableShare()->getPath());
+      TableIdentifier identifier(first_table->getSchemaName(), first_table->getTableName(), table->getMutableShare()->getPath());
       TableIdentifier new_identifier(select_lex->db ? select_lex->db : first_table->getSchemaName(),
-                                     session->lex->name.str ? session->lex->name.str : first_table->table_name,
+                                     session->lex->name.str ? session->lex->name.str : first_table->getTableName(),
                                      table->getMutableShare()->getPath());
 
       res= alter_table(session, 
@@ -1498,7 +1498,8 @@
 
       memset(&tables, 0, sizeof(tables));
       tables.table= from;
-      tables.alias= tables.table_name= const_cast<char *>(from->getMutableShare()->getTableName());
+      tables.setTableName(const_cast<char *>(from->getMutableShare()->getTableName()));
+      tables.alias= const_cast<char *>(tables.getTableName());
       tables.setSchemaName(const_cast<char *>(from->getMutableShare()->getSchemaName()));
       error= 1;
 
@@ -1637,7 +1638,7 @@
     TableList tbl;
     tbl.setSchemaName(const_cast<char *>(identifier.getSchemaName().c_str()));
     tbl.alias= const_cast<char *>(identifier.getTableName().c_str());
-    tbl.table_name= const_cast<char *>(identifier.getTableName().c_str());
+    tbl.setTableName(const_cast<char *>(identifier.getTableName().c_str()));
 
     /* Table is in session->temporary_tables */
     new_table= session->openTable(&tbl, (bool*) 0, DRIZZLE_LOCK_IGNORE_FLUSH);

=== modified file 'drizzled/statement/create_index.cc'
--- drizzled/statement/create_index.cc	2010-10-23 22:28:30 +0000
+++ drizzled/statement/create_index.cc	2010-10-24 01:34:39 +0000
@@ -36,7 +36,7 @@
   /* Chicken/Egg... we need to search for the table, to know if the table exists, so we can build a full identifier from it */
   message::Table original_table_message;
   {
-    TableIdentifier identifier(first_table->getSchemaName(), first_table->table_name);
+    TableIdentifier identifier(first_table->getSchemaName(), first_table->getTableName());
     if (plugin::StorageEngine::getTableDefinition(*session, identifier, original_table_message) != EEXIST)
     {
       my_error(ER_BAD_TABLE_ERROR, MYF(0), identifier.getSQLPath().c_str());
@@ -62,7 +62,7 @@
   bool res;
   if (original_table_message.type() == message::Table::STANDARD )
   {
-    TableIdentifier identifier(first_table->getSchemaName(), first_table->table_name);
+    TableIdentifier identifier(first_table->getSchemaName(), first_table->getTableName());
     create_info.default_table_charset= plugin::StorageEngine::getSchemaCollation(identifier);
 
     res= alter_table(session, 
@@ -77,11 +77,11 @@
   }
   else
   {
-    TableIdentifier catch22(first_table->getSchemaName(), first_table->table_name);
+    TableIdentifier catch22(first_table->getSchemaName(), first_table->getTableName());
     Table *table= session->find_temporary_table(catch22);
     assert(table);
     {
-      TableIdentifier identifier(first_table->getSchemaName(), first_table->table_name, table->getMutableShare()->getPath());
+      TableIdentifier identifier(first_table->getSchemaName(), first_table->getTableName(), table->getMutableShare()->getPath());
       create_info.default_table_charset= plugin::StorageEngine::getSchemaCollation(identifier);
 
       res= alter_table(session, 

=== modified file 'drizzled/statement/create_table.cc'
--- drizzled/statement/create_table.cc	2010-10-23 22:28:30 +0000
+++ drizzled/statement/create_table.cc	2010-10-24 01:34:39 +0000
@@ -83,7 +83,7 @@
   drizzled::message::init(create_table_message, create_table_message.name(), create_table->getSchemaName(), create_info.db_type->getName());
 
   TableIdentifier new_table_identifier(create_table->getSchemaName(),
-                                       create_table->table_name,
+                                       create_table->getTableName(),
                                        create_table_message.type());
 
   if (create_table_precheck(new_table_identifier))

=== modified file 'drizzled/statement/drop_index.cc'
--- drizzled/statement/drop_index.cc	2010-10-23 22:28:30 +0000
+++ drizzled/statement/drop_index.cc	2010-10-24 01:34:39 +0000
@@ -36,7 +36,7 @@
   /* Chicken/Egg... we need to search for the table, to know if the table exists, so we can build a full identifier from it */
   message::Table original_table_message;
   {
-    TableIdentifier identifier(first_table->getSchemaName(), first_table->table_name);
+    TableIdentifier identifier(first_table->getSchemaName(), first_table->getTableName());
     if (plugin::StorageEngine::getTableDefinition(*session, identifier, original_table_message) != EEXIST)
     {
       my_error(ER_BAD_TABLE_ERROR, MYF(0), identifier.getSQLPath().c_str());
@@ -67,7 +67,7 @@
   bool res;
   if (original_table_message.type() == message::Table::STANDARD )
   {
-    TableIdentifier identifier(first_table->getSchemaName(), first_table->table_name);
+    TableIdentifier identifier(first_table->getSchemaName(), first_table->getTableName());
 
     create_info.default_table_charset= plugin::StorageEngine::getSchemaCollation(identifier);
 
@@ -83,11 +83,11 @@
   }
   else
   {
-    TableIdentifier catch22(first_table->getSchemaName(), first_table->table_name);
+    TableIdentifier catch22(first_table->getSchemaName(), first_table->getTableName());
     Table *table= session->find_temporary_table(catch22);
     assert(table);
     {
-      TableIdentifier identifier(first_table->getSchemaName(), first_table->table_name, table->getShare()->getPath());
+      TableIdentifier identifier(first_table->getSchemaName(), first_table->getTableName(), table->getShare()->getPath());
       create_info.default_table_charset= plugin::StorageEngine::getSchemaCollation(identifier);
 
       res= alter_table(session, 

=== modified file 'drizzled/statement/rename_table.cc'
--- drizzled/statement/rename_table.cc	2010-10-23 22:28:30 +0000
+++ drizzled/statement/rename_table.cc	2010-10-24 01:34:39 +0000
@@ -147,7 +147,7 @@
   const char *new_alias, *old_alias;
 
   {
-    old_alias= ren_table->table_name;
+    old_alias= ren_table->getTableName();
     new_alias= new_table_name;
   }
 
@@ -186,7 +186,7 @@
   for (ren_table= table_list; ren_table; ren_table= new_table->next_local)
   {
     new_table= ren_table->next_local;
-    if (rename(ren_table, new_table->getSchemaName(), new_table->table_name, skip_error))
+    if (rename(ren_table, new_table->getSchemaName(), new_table->getTableName(), skip_error))
       return ren_table;
   }
   return 0;

=== modified file 'drizzled/table_list.h'
--- drizzled/table_list.h	2010-10-23 22:28:30 +0000
+++ drizzled/table_list.h	2010-10-24 01:34:39 +0000
@@ -149,7 +149,26 @@
   }
 
   const char *alias;
+
+private:
   char *table_name;
+
+public:
+  const char *getTableName()
+  {
+    return table_name;
+  }
+
+  char **getTableNamePtr()
+  {
+    return &table_name;
+  }
+
+  void setTableName(char *arg)
+  {
+    table_name= arg;
+  }
+
   char *option; ///< Used by cache index
   Item *on_expr; ///< Used with outer join
   Table *table; ///< opened table

